@@ -1,5 +1,5 @@
 """
-$Id: interfaces.py 2823 2009-07-28 22:34:48Z larubbio $
+$Id: interfaces.py 3195 2009-11-04 07:35:12Z hannesc $
 """
 
 from zope import schema
@@ -329,7 +329,7 @@ class IGetPaidManagementCurrencyOptions( igetpaid.IPersistentOptions ):
 
     digits_after_decimal = schema.TextLine( title = _(u"Number of Digits After Decimal"),
                                    required = False,
-                                   default = u""
+                                   default = u"2"
                                  )
 
     us_currency_formatting = schema.TextLine( title = _(u"US Currency Formatting"),
@@ -512,3 +512,5 @@ class INamedOrderList(IContainer):
     contains(INamedOrder)
 
 
+class ICurrencyFormatter(Interface):
+    """ """
\ No newline at end of file
